@@ -5,14 +5,14 @@ from streamlink.plugin.api import http
 from streamlink.plugin.api import useragents
 from streamlink.stream import HLSStream
 
-EMBED_URL_1 = "http://www.canlitv.life/kanallar.php?kanal={0}"
+EMBED_URL_1 = "http://www.canlitv.plus/kanallar.php?kanal={0}"
 EMBED_URL_2 = "http://www.ecanlitvizle.net/embed.php?kanal={0}"
 
 _m3u8_re = re.compile(r"""file\s*:\s*['"](?P<url>[^"']+)['"]""")
 _url_re = re.compile(r"""http(s)?://(?:www\.)?(?P<domain>
-    canlitv\.(com|life)
+    canlitv\.(com|plus)
     |
-    canlitvlive\.(co|live)
+    canlitvlive\.(io|co|live|site)
     |
     ecanlitvizle\.net
     )
@@ -35,7 +35,7 @@ class Canlitv(Plugin):
             "User-Agent": useragents.FIREFOX
         }
 
-        if domain == "canlitv.life":
+        if domain == "canlitv.plus":
             res = http.get(EMBED_URL_1.format(channel), headers=headers)
         elif domain == "ecanlitvizle.net":
             res = http.get(EMBED_URL_2.format(channel), headers=headers)
@@ -47,6 +47,9 @@ class Canlitv(Plugin):
         if url_match:
             hls_url = url_match.group("url")
 
+            if domain in ("canlitvlive.live", "canlitvlive.site"):
+                 hls_url = "http:" + hls_url
+
             self.logger.debug("Found URL: {0}".format(hls_url))
 
             try:
